UnitAgent<P extends Paper> class

The agent is specialized for Unit.

Inheritance

Constructors

UnitAgent()

Properties

hashCode int
The hash code for this object.
no setterinherited
isAbsence bool
Indicate whether the unit is being disposed or have not been initialized
no setterinherited
isInit bool
Indicate whether the unit is initialized and registered into the tree
no setterinherited
isInitializing bool
Indicate whether the unit is being initialized
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

dispose() → void
init() Future<void>
log(Unit<P> builder(UnitAgent<P> agent)) UnitAgent<P>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
process(P paper) Future<void>
report<R extends P>() Future<R?>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited